==> interactive-style-1.5.0.tgz: package/config/rollup.esm.js <==
import path from 'path';
import glob from 'glob';
import babel from 'rollup-plugin-babel';
import resolve from 'rollup-plugin-node-resolve';
import json from 'rollup-plugin-json';
import postcss from 'rollup-plugin-postcss';
import pkg from '../package.json';

const babelOpts = {
  babelrc: false,
  exclude: 'node_modules/**',
  presets: [
    ['@babel/preset-env', { modules: false }],
    '@babel/preset-react',
  ],
  plugins: [
    '@babel/proposal-class-properties',
    '@babel/plugin-proposal-export-namespace-from',
    [ 'babel-plugin-webpack-alias', { 'config': './config/webpack.babel.js' } ],
  ],
};

const commonConfig = {
  external: [
    'react',
    'react-dom',
    ...Object.keys(pkg.dependencies),
  ],
};

export default [...glob.sync('./src/components/*/index.js'), ...glob.sync('./src/constants/*/index.js')].map(file => {
  const dirName = file.split(path.sep).slice(-3, -1)[0];
  const componentName = file.split(path.sep).slice(-2, -1)[0];
  const config = {
    input: file,
    output: {
      file: path.resolve(process.cwd(), `dist/${dirName}/${componentName}/index.js`),
      format: 'es',
      banner: dirName === 'components' ? 'import \'./index.css\';' : '',
    },
    plugins: [
      babel(babelOpts),
      json(),
      postcss({
        modules: {
          generateScopedName: 'politico_style___[hash:base64:10]',
        },
        extract: true,
      }),
      resolve({
        preferBuiltins: true,
        extensions: ['.js', '.jsx'],
        modulesOnly: true,
      }),
    ],
  };
  return {
    ...config,
    ...commonConfig,
  };
});

==> interactive-style-1.6.1.tgz: package/config/rollup.esm.js <==
import path from 'path';
import glob from 'glob';
import babel from 'rollup-plugin-babel';
import resolve from 'rollup-plugin-node-resolve';
import json from 'rollup-plugin-json';
import postcss from 'rollup-plugin-postcss';
import pkg from '../package.json';

const babelOpts = {
  babelrc: false,
  exclude: 'node_modules/**',
  presets: [
    ['@babel/preset-env', { modules: false }],
    '@babel/preset-react',
  ],
  plugins: [
    '@babel/proposal-class-properties',
    '@babel/plugin-proposal-export-namespace-from',
    [ 'babel-plugin-webpack-alias', { 'config': './config/webpack.babel.js' } ],
  ],
};

const commonConfig = {
  external: [
    'react',
    'react-dom',
    ...Object.keys(pkg.dependencies),
  ],
};

export default [...glob.sync('./src/components/*/index.js'), ...glob.sync('./src/constants/*/index.js')].map(file => {
  const dirName = file.split(path.sep).slice(-3, -1)[0];
  const componentName = file.split(path.sep).slice(-2, -1)[0];
  const config = {
    input: file,
    output: {
      file: path.resolve(process.cwd(), `dist/${dirName}/${componentName}/index.js`),
      format: 'es',
      banner: dirName === 'components' && componentName !== 'Head' ? 'import \'./index.css\';' : '',
    },
    plugins: [
      babel(babelOpts),
      json(),
      postcss({
        modules: {
          generateScopedName: 'politico_style___[hash:base64:10]',
        },
        extract: true,
      }),
      resolve({
        preferBuiltins: true,
        extensions: ['.js', '.jsx'],
        modulesOnly: true,
      }),
    ],
  };
  return {
    ...config,
    ...commonConfig,
  };
});
